<!-- 
##
##  demo.errsyn -- ePerl demonstration webpage
##  Copyright (c) 1996,1997 Ralf S. Engelschall, All Rights Reserved. 
##
-->
<html>
<head>
<title>demo.errsyn</title>
</head>
<body>
<blockquote>
<blockquote>
<h1>demo.errsyn</h1>
<h2>ePerl error page: caused by a syntax error</h2>

<?
#   the following Pascal'isch line leads
#   to a syntax error inside ePerl

$name := "value";
!>

</blockquote>
</blockquote>
</body>
</html>
