<html>
<!-- 
##
##  demo.lwp -- ePerl demonstration webpage
##  Copyright (c) 1996,1997 Ralf S. Engelschall, All Rights Reserved. 
##
-->
<head>
<title>demo.pp</title>
</head>
<body>
<blockquote>
<blockquote>
<h1>demo.pp</h1>
<h2>Special feature: the ePerl preprocessor</h2>

This demonstrates how one can use the ePerl preprocessor.  We again (as in
demo.lwp) retrieve a file via HTTP. As an example the ePerl distribution
README file is fetched from
<tt>http://www.engelschall.com/sw/eperl/distrib/eperl-SNAP/</tt>.

<p>
And here comes the file:

<pre>
#sinclude "http://www.engelschall.com/sw/eperl/distrib/eperl-SNAP/README"
</pre>

</blockquote>
</blockquote>
</body>
</html>
