<!-- 
##
##  demo.env -- ePerl demonstration webpage
##  Copyright (c) 1996,1997 Ralf S. Engelschall, All Rights Reserved. 
##
-->
<html>
<head>
<title>demo.env</title>
</head>
<body>
<blockquote>
<blockquote>
<h1>demo.env</h1>
<h2>Standard CGI Example: Environment</h1>
<p>

This prints out the CGI environment provided by the Webserver as a sorted list
consisting of key/value pairs.

<p>
<pre>
<? my $key;
   foreach $key (sort(keys(%ENV))) { 
       print "$key=$ENV{$key}\n"; 
   }
!>
</pre>

</blockquote>
</blockquote>
</body>
</html>
