Content-type: text/plain

<?
##
##  demo.text -- ePerl demonstration webpage
##  Copyright (c) 1996,1997 Ralf S. Engelschall, All Rights Reserved. 
!>

demo.func

Low-level HTTP programming

This demonstrates how one can prefix the ePerl file with plain
HTTP headers which are directly put into the HTTP response header
block.

