<!-- 
##
##  demo.errout -- ePerl demonstration webpage
##  Copyright (c) 1996,1997 Ralf S. Engelschall, All Rights Reserved. 
##
-->
<html>
<head>
<title>demo.errout</title>
</head>
<body>
<blockquote>
<blockquote>
<h2>ePerl error page: caused by output on STDERR</h2>

<p>
First pure text, then...
<? print STDERR "data on STDERR which leads to an error"; !>
...and then again pure text.

</blockquote>
</blockquote>
</body>
</html>
